@@ -9,11 +9,11 @@ SeaBASS::File - Object-oriented interface for reading/writing SeaBASS files
 
 =head1 VERSION
 
-version 0.142140
+version 0.151910
 
 =cut
 
-our $VERSION = '0.142140'; # VERSION
+our $VERSION = '0.151910'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -331,8 +331,8 @@ our $DEFAULT_MISSING = -999;
 # your IQ is the percentage chance that it won't make sense
 # IE: my IQ = 40, I have a 60% chance of it making sense to me
 my %ANCILLARY = (
-	'lat'       => [ { 'north_latitude'    => qr/^(.*?)\[/ }, ],
-	'lon'       => [ { 'east_longitude'    => qr/^(.*?)\[/ }, ],
+	'lat'       => [ { 'north_latitude'    => qr/^(.*?)$/ }, { 'south_latitude' => qr/^(.*?)$/ } ],
+	'lon'       => [ { 'east_longitude'    => qr/^(.*?)$/ }, { 'west_longitude' => qr/^(.*?)$/ } ],
 	'depth'     => [ { 'measurement_depth' => qr/^(.*?)$/ }, ],
 	'date_time' => [ '$date $time', ],
 	'date' => [ [ \&julian_to_greg, '$year$julian' ], [ \&julian_to_greg, '$year$jd' ], '$year$month$day', ],
@@ -1568,7 +1568,7 @@ sub write {
 					foreach my $comment ( @{ $self->{'comments'} } ) {
 						print "$comment\n";
 					}
-					if ( $#{ $self->{'comments'} } == -1 && $add_missing_headers ) {
+					if ( !@{ $self->{'comments'} } && $add_missing_headers ) {
 						print "! Comments: \n!\n";
 					}
 					if ( !exists( $self->{'headers'}{"$slash$header"} ) ) {
@@ -1583,8 +1583,24 @@ sub write {
 				} elsif ( exists( $self->{'headers'}{"$slash$header"} ) ) {
 					if ( $header =~ /_header/ ) {
 						print "/$header\n";
-					} else {
-						print '/', $header, '=', $self->{'headers'}{"$slash$header"}, "\n";
+					} elsif (length($self->{'headers'}{"$slash$header"})) {
+						my $v = $self->{'headers'}{"$slash$header"};
+						if ( $header =~ /_latitude|_longitude/ ) {
+							print "/$header=$v\[deg]\n";
+						} elsif ( $header =~ /_time/ ) {
+							print "/$header=$v\[gmt]\n";
+						} else {
+							print "/$header=$v\n";
+						}
+#						print '/', $header, '=', $self->{'headers'}{"$slash$header"}, "\n";
+					} elsif ($add_missing_headers) {
+						if ( $header =~ /_latitude|_longitude/ ) {
+							print "/$header=$add_missing_headers\[deg]\n";
+						} elsif ( $header =~ /_time/ ) {
+							print "/$header=$add_missing_headers\[gmt]\n";
+						} else {
+							print "/$header=$add_missing_headers\n";
+						}
 					}
 				} elsif ($add_missing_headers) {
 					if ( $header =~ /_latitude|_longitude/ ) {
@@ -1845,22 +1861,11 @@ sub create_blank_file {
 	$self->{'options'}{'fill_ancillary_data'} = 0;
 
 	my $slash = ( $self->{'options'}{'keep_slashes'} ? '/' : '' );
-	my $add_missing_headers = $self->{'options'}{'add_empty_headers'};
-	if ( $add_missing_headers && $add_missing_headers eq '1' ) {
-		$add_missing_headers = 'NA';
-	}
-	if ( !$self->{'options'}{'preserve_case'} ) {
-		$add_missing_headers = lc( $add_missing_headers || '' );
-	}
-	if ($add_missing_headers) {
+	if ($self->{'options'}{'add_empty_headers'}) {
 		foreach (@ALL_HEADERS) {
 			if ( !exists( $self->{'headers'}{"${slash}$_"} ) ) {
-				$self->{'headers'}{"${slash}$_"} = $add_missing_headers;
-				if ( $_ =~ /_latitude|_longitude/ ) {
-					$self->{'headers'}{"${slash}$_"} .= '[deg]';
-				} elsif ( $_ =~ /_time/ ) {
-					$self->{'headers'}{"${slash}$_"} .= '[gmt]';
-				} elsif ( $_ eq 'missing' ) {
+				$self->{'headers'}{"${slash}$_"} = '';
+				if ( $_ eq 'missing' ) {
 					$self->{'headers'}{"${slash}missing"} = $DEFAULT_MISSING;
 				}
 			} ## end if (!exists($self->{'headers'...}))
@@ -2023,11 +2028,18 @@ sub read_headers {
 		$headers{"${slash}units"} = join( ',', @new_units1 );
 	} ## end else [ if ($headers{"${slash}units"...})]
 
-	if ( scalar( @{ $self->{'fields'} } ) != scalar( @{ $self->{'units'} } ) ) {
+	if ( @{$self->{'fields'}} != @{$self->{'units'}} ) {
 		if ( $strict & STRICT_READ ) {
 			carp("/fields and /units don't match up");
+			$success = 0;
+		} else {
+			while (@{$self->{'fields'}} > @{$self->{'units'}}){
+				push(@{$self->{'units'}}, 'unitless');
+			}
+			while (@{$self->{'fields'}} < @{$self->{'units'}}){
+				pop(@{$self->{'units'}});
+			}
 		}
-		$success = 0;
 	}
 
 	unless ($success) {
@@ -2124,9 +2136,6 @@ variables in place to prepare them for use.
 Returns false if there was a problem with the inputs, such as C<strict> is set
 and an invalid header was passed in.
 
-If C<strict> is not set, this function will add any missing [deg]/[gmt] labels
-to location and time headers if they are not present.
-
 C<validate_header> will set C</missing> to C<$DEFAULT_MISSING> (C<-999>) if it
 is blank or undefined.
 
@@ -2155,7 +2164,7 @@ sub validate_header {
 			carp("$k missing value");
 			$success = 0;
 		} else {
-			$v = "NA";
+			$v = "";
 		}
 	} ## end if (length($v) == 0 &&...)
 
@@ -2183,20 +2192,10 @@ sub validate_header {
 		}
 	} ## end else [ if ($self->{'options'}...)]
 
-	if ( $k =~ /_latitude|_longitude/ && $v !~ /\[deg\]$/i ) {
-		if ($strict) {
-			carp("$k missing [deg]");
-			$success = 0;
-		} else {
-			$v .= '[deg]';
-		}
-	} elsif ( $k =~ /_time/ && $v !~ /\[gmt\]$/i ) {
-		if ($strict) {
-			carp("$k missing [gmt]");
-			$success = 0;
-		} else {
-			$v .= '[gmt]';
-		}
+	if ( $k =~ /_latitude|_longitude/){
+		$v =~ s/\[deg\]$//i;
+	} elsif ( $k =~ /_time/){
+		$v =~ s/\[gmt\]$//i;
 	} elsif ( $k =~ m"^/?delimiter$" ) {
 		unless ( $self->set_delim( $strict, $v ) ) {
 			if ($strict) {
@@ -2300,10 +2299,10 @@ sub add_and_remove_fields {
 		}
 	} ## end while (my ($variable, $pad...))
 
-	if ( $self->{'ancillary'} ) {
+	if ( defined($self->{'ancillary'}) ) {
 		$self->{'ancillary_tmp'} = {};
 		for my $variable (@FILL_ANCILLARY_DATA) {
-			if ( $self->{'ancillary'}{$variable} ) {
+			if ( defined($self->{'ancillary'}{$variable}) ) {
 				my $value = $self->extrapolate_variables( $missing, $self->{'ancillary'}{$variable}, $hash );
 				if ( defined($value) ) {
 					$hash->{$variable} = $value;
